@@ -1718,7 +1718,6 @@ static void
 osm_gps_map_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
     g_return_if_fail (OSM_IS_GPS_MAP (object));
-    float lat,lon;
     OsmGpsMap *map = OSM_GPS_MAP(object);
     OsmGpsMapPrivate *priv = map->priv;
 
@@ -1755,14 +1754,10 @@ osm_gps_map_get_property (GObject *object, guint prop_id, GValue *value, GParamS
             g_value_set_int(value, priv->min_zoom);
             break;
         case PROP_LATITUDE:
-            lat = pixel2lat(priv->map_zoom,
-                            priv->map_y + (GTK_WIDGET(map)->allocation.height / 2));
-            g_value_set_float(value, rad2deg(lat));
+            g_value_set_float(value, rad2deg(priv->center_rlat));
             break;
         case PROP_LONGITUDE:
-            lon = pixel2lon(priv->map_zoom,
-                            priv->map_x + (GTK_WIDGET(map)->allocation.width / 2));
-            g_value_set_float(value, rad2deg(lon));
+            g_value_set_float(value, rad2deg(priv->center_rlon));
             break;
         case PROP_MAP_X:
             g_value_set_int(value, priv->map_x);
@@ -2616,9 +2611,13 @@ osm_gps_map_set_zoom (OsmGpsMap *map, int zoom)
         priv->map_x = lon2pixel(priv->map_zoom, priv->center_rlon) - width_center;
         priv->map_y = lat2pixel(priv->map_zoom, priv->center_rlat) - height_center;
 
+        factor = pow(2, priv->map_zoom-zoom_old);
         g_debug("Zoom changed from %d to %d factor:%f x:%d",
                 zoom_old, priv->map_zoom, factor, priv->map_x);
 
+        /* adjust gps precision indicator */
+        priv->ui_gps_point_outer_radius *= factor;
+
 #ifdef ENABLE_OSD
         /* OSD may contain a scale, so we may have to re-render it */
         if(priv->osd && OSM_IS_GPS_MAP (priv->osd->widget))
@@ -2644,6 +2643,29 @@ osm_gps_map_add_track (OsmGpsMap *map, GSList *track)
     }
 }
 
+void
+osm_gps_map_replace_track (OsmGpsMap *map, GSList *old_track, GSList *new_track)
+{
+    OsmGpsMapPrivate *priv;
+
+    if(!old_track) {
+        osm_gps_map_add_track (map, new_track);
+        return;
+    }
+
+    g_return_if_fail (OSM_IS_GPS_MAP (map));
+    priv = map->priv;
+
+    GSList *old = g_slist_find(priv->tracks, old_track);
+    if(!old) {
+        g_warning("track to be replaced not found");
+        return;
+    }
+
+    old->data = new_track;
+    osm_gps_map_map_redraw_idle(map);
+}
+
 void
 osm_gps_map_clear_tracks (OsmGpsMap *map)
 {
